====================
Avocado User's Guide
====================

Contents:

.. toctree::
   :maxdepth: 2

   Introduction
   GetStartedGuide
   WritingTests
   ResultFormats
   Configuration
   Loaders
   LoggingSystem
   Sysinfo
   TestParameters
   Replay
   Diff
   RunningTestsRemotely
   SubclassingAvocado
   DebuggingWithGDB
   WrapProcess
   Plugins

=========
Utilities
=========

.. toctree::
   :maxdepth: 2

   utils/index

================
Optional Plugins
================

.. toctree::
   :maxdepth: 2

   optional_plugins/index

===============================
Advanced Topics and Maintenance
===============================

.. toctree::
   :maxdepth: 2

   ReferenceGuide
   ContributionGuide
   DevelopmentTips
   MaintenanceGuide
   OtherResources

.. _api-reference:

=============
API Reference
=============

.. toctree::
   :maxdepth: 1

   api/test/avocado.rst
   api/utils/avocado.utils.rst
   api/core/avocado.core.rst
   api/plugins/avocado.plugins.rst
   api/optional-plugins/index.rst

=====================
Avocado Release Notes
=====================

.. toctree::
   :maxdepth: 1

   release_notes/index

===========================
Request For Comments (RFCs)
===========================

.. toctree::
   :maxdepth: 1

   rfcs/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
